@@ -277,7 +277,8 @@ netk_pager_size_request (GtkWidget * widget, GtkRequisition * requisition)
     if (pager->priv->orientation == GTK_ORIENTATION_VERTICAL)
     {
         screen_aspect =
-            (double) gdk_screen_height () / (double) gdk_screen_width ();
+            (double) netk_screen_get_height (pager->priv->screen) /
+            (double) netk_screen_get_width (pager->priv->screen);
 
         /* TODO: Handle NETK_PAGER_DISPLAY_NAME for this case */
 
@@ -1081,7 +1082,7 @@ netk_pager_button_press (GtkWidget * widget, GdkEventButton * event)
             {
                 if (event->button == 1)
                 {
-                    // netk_window_activate (win);
+                    /* netk_window_activate (win); */
                     pager->priv->drag_window = win;
                     pager->priv->drag_start_x = event->x;
                     pager->priv->drag_start_y = event->y;
@@ -1490,7 +1491,6 @@ static void
 window_geometry_changed_callback (NetkWindow * window, gpointer data)
 {
     NetkPager *pager = NETK_PAGER (data);
-
     gtk_widget_queue_draw (GTK_WIDGET (pager));
 }
 
