@@ -253,7 +253,10 @@ p_netk_get_text_property (Window xwindow, Atom atom)
     if (XGetTextProperty (gdk_display, xwindow, &text, atom))
     {
         retval = text_property_to_utf8 (&text);
-
+        if (retval)
+        {
+            utf8_string_remove_controls((gchar *) retval, -1, NULL);
+        }
         if (text.nitems > 0)
             XFree (text.value);
     }
@@ -328,7 +331,7 @@ p_netk_get_utf8_property (Window xwindow, Atom atom)
     if (err != Success || result != Success)
         return NULL;
 
-    if (type != utf8_string || format != 8 || nitems == 0)
+    if (type != utf8_string || format != 8 || nitems == 0 || !val)
     {
         if (val)
             XFree (val);
@@ -492,7 +495,7 @@ p_netk_get_utf8_list (Window xwindow, Atom atom)
                             &bytes_after, (guchar **)&val);
     err = p_netk_error_trap_pop ();
 
-    if (err != Success || result != Success)
+    if (err != Success || result != Success || !val)
         return NULL;
 
     if (type != utf8_string || format != 8 || nitems == 0)
